@@ -19,7 +19,6 @@ namespace KCDDB
     Q_OBJECT
 
     public:
-
       AsyncMusicBrainzLookup();
       virtual ~AsyncMusicBrainzLookup();
 
@@ -28,14 +27,10 @@ namespace KCDDB
       CDInfoList lookupResponse() const;
 
     Q_SIGNALS:
-
       void finished( KCDDB::Result );
 
     protected Q_SLOTS:
-      void lookupFinished( );
-
-    private:
-      LookupThread* m_lookupThread;
+      void processLookupResult( KCDDB::Result result, KCDDB::CDInfoList lookupResponse );
   };
 }
 
